@@ -1,7 +1,7 @@
 # Mail::Header.pm
 #
 # Copyright (c) 1995-2001 Graham Barr <gbarr@pobox.com>. All rights reserved.
-# Copyright (c) 2002-2003 Mark Overmeer <mailtools@overmeer.net>
+# Copyright (c) 2002-2005 Mark Overmeer <mailtools@overmeer.net>
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -20,7 +20,7 @@ use strict;
 use Carp;
 use vars qw($VERSION $FIELD_NAME);
 
-$VERSION = "1.66";
+$VERSION = "1.68";
 
 my $MAIL_FROM = 'KEEP';
 my %HDR_LENGTHS = ();
@@ -106,7 +106,7 @@ sub _fold_line
  my $min = int($maxlen * 4 / 5) - 4;
  my $ml = $maxlen;
 
- $_[0] =~ s/\s*[\r\n]+\s*/ /og; # Compress any white space around a newline
+ $_[0] =~ s/[\r\n]+/ /og;       # Remove new-lines
  $_[0] =~ s/\s*\Z/\n/so;        # End line with a EOLN
 
  return if $_[0] =~ /^From\s/io;
